@@ -3,7 +3,7 @@ package Bit::Manip::PP;
 use warnings;
 use strict;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -171,6 +171,7 @@ Bit::Manip::PP - Pure Perl functions to simplify bit string manipulation
 
 =for html
 <a href="http://travis-ci.org/stevieb9/bit-manip-pp"><img src="https://secure.travis-ci.org/stevieb9/bit-manip-pp.png"/>
+<a href="https://ci.appveyor.com/project/stevieb9/p5-hook-output-tiny"><img src="https://ci.appveyor.com/api/projects/status/br01o72b3if3plsw/branch/master?svg=true"/></a>
 <a href='https://coveralls.io/github/stevieb9/bit-manip-pp?branch=master'><img src='https://coveralls.io/repos/stevieb9/bit-manip-pp/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
@@ -234,6 +235,10 @@ Provides functions to aid in bit manipulation (set, unset, toggle, shifting)
 etc. Particularly useful for embedded programming and writing device
 communication software.
 
+In functions that modify your data, you can pass your data by value and get the
+modified value returned, or pass it in as a scalar reference and we'll modify
+the data inline.
+
 Currently, up to 32-bit integers are supported.
 
 =head1 EXPORT_OK
